% Dynamic Macroeconomics
% Problem Set 1 - Evaluating Model
% Written by Christian Rhl
% This version 17.10.2014

clc; clear all; close all;

% Import the PennWorldTable
load('PWT80');

% Generate useable year numbers
temp = datevec(PWT.year);
year = temp(:,1);
T = find(year == 2010); % Focus on 2011 data

% Extract relevant variables
realgdp = PWT.rgdpe(:, T);
capital = PWT.ck(:,T);
population = PWT.pop(:, T);
realgdp_capita = realgdp./population;
capital_capita = capital./population;

% Find index for USA
country = PWT.country;
temp = ismember(country, 'United States');
USA = find(temp == 1);

% Construct variables relative to US
realgdp_capita_us = realgdp_capita/realgdp_capita(USA);
capital_capita_us = capital_capita/capital_capita(USA);

% Drop countries with realgdp_capita_us > 1
I = realgdp_capita_us > 1;
realgdp_capita_us(I) =  [];
capital_capita_us(I) = [];
country(I) = [];

% Predicted GDP per capita relative to US (assuming A = 1)
y1 = 1*capital_capita_us.^(1/3);

figure;
scatter(realgdp_capita_us, y1);
axis([1/128 1.1 1/31 1.1]);
line(realgdp_capita_us, realgdp_capita_us, 'LineWidth',4,'Color',[1 0 0]);
title('Prediction for Real GDP per capita (US = 1)');
xlabel('Actual per capita GDP, 2010')';
ylabel('Predicted y');
legend('GDP', '45 line');


% Implied value for A
A = realgdp_capita_us./(capital_capita_us.^(1/3));

figure;
scatter(realgdp_capita_us, A);
axis([1/128 1.1 1/32 1.1]);
title('Prediction for Real GDP per capita (US = 1)');
xlabel('Actual per capita GDP, 2010')';
ylabel('Implied A');